@@ -6,10 +6,7 @@ use v5.14.2;
 
 use warnings;
 
-use subs qw();
-use vars qw($VERSION);
-
-$VERSION = '1.001';
+our $VERSION = '1.002';
 
 UNITCHECK {
 sub _running_under_docreader {
@@ -38,11 +35,11 @@ __PACKAGE__->$method(@ARGV) if defined $method;
 
 =head1 NAME
 
-__PACKAGE__ - A demonstration of module ideas
+Modulino::Demo - A demonstration of module ideas
 
 =head1 SYNOPSIS
 
-	use __PACKAGE__;
+	use Modulino::Demo;
 
 =head1 DESCRIPTION
 
@@ -160,7 +157,7 @@ sub _test_doc {
 
 This source is in Github:
 
-	http://github.com/briandfoy/modulino-demo/
+	https://github.com/briandfoy/modulino-demo/
 
 =head1 AUTHOR
 
@@ -168,9 +165,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2012-2014, brian d foy, All Rights Reserved.
+Copyright © 2012-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
-You may redistribute this under the same terms as Perl itself.
+You may redistribute this under the terms as the Artistic License 2.0.
 
 =cut
 
