@@ -6,18 +6,15 @@ use v5.14.2;
 
 use warnings;
 
-use subs qw();
-use vars qw($VERSION);
-
 require Modulino::Base;
 
-$VERSION = '1.001';
+our $VERSION = '1.002';
 
 =encoding utf8
 
 =head1 NAME
 
-Modulino::Demo - A demonstration of modulino ideas
+Modulino::Demo3 - A demonstration of modulino ideas
 
 =head1 SYNOPSIS
 
@@ -136,7 +133,7 @@ sub _test_doc {
 
 This source is in Github:
 
-	http://github.com/briandfoy/modulino-demo/
+	https://github.com/briandfoy/modulino-demo/
 
 =head1 AUTHOR
 
@@ -144,9 +141,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2012-2014, brian d foy, All Rights Reserved.
+Copyright © 2012-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
-You may redistribute this under the same terms as Perl itself.
+You may redistribute this under the terms of the Artistic License 2.0.
 
 =cut
 
